@@ -29,15 +29,28 @@
 
 /* The Magic Incantations for exporting the functions from DLLs under 
  * Windows. */
-#define LDPUBLIC32 
-#define LDPUBLIC16
-
+#ifdef WIN16
+# define LDPUBLIC16 __export __far __pascal
+# define LDPUBLIC32
+#else   /* def WIN16 */
+# ifdef WIN32
+# define LDPUBLIC16 __stdcall
+#  ifdef LIBDSK_EXPORTS
+#   define LDPUBLIC32 __declspec(dllexport)
+#  else  /* def LIBDSK_EXPORTS */
+#   define LDPUBLIC32 __declspec(dllimport)
+#  endif /* def LIBDSK_EXPORTS */ 
+# else   /* def WIN32 */
+#  define LDPUBLIC32 
+#  define LDPUBLIC16
+# endif /* def WIN32 */
+#endif  /* def WIN16 */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#define LIBDSK_VERSION "0.9.9"
+#define LIBDSK_VERSION "1.0.0"
 
 /************************* TYPES ********************************/
 
